#!/bin/bash

: ${TRAPLINKER_SR_ARCH:="x86_64"}
: ${ALKEMIST_RUNTIME_MODE:=0}

if [ -z "${LFR_ROOT_PATH}" ]; then
  source /etc/profile.d/alkemist-lfr.sh
  if [ -z "${LFR_ROOT_PATH}" ]; then
    echo "ERROR: LFR_ROOT_PATH is not set. Please set LFR_ROOT_PATH to the the path of your LFR installation. Default install location is /opt/alkemist/lfr"
    exit -1
  fi
fi

if [ ! -f "${LFR_ROOT_PATH}/bin/traplinker" ]; then
  echo "ERROR: LFR_ROOT_PATH does not point to a valid LFR installation. Please set LFR_ROOT_PATH to the the path of your LFR installation. Default install location is /opt/alkemist/lfr"
  exit -1
fi

if [ -d "${LFR_ROOT_PATH}/binutils/" ]; then
	orig_ld="${LFR_ROOT_PATH}/binutils/ld-new"
fi

# Only copy libraries and run ldconfig when we are in Docker
if grep -q 'docker\|lxc\|kubepod' /proc/1/cgroup ; then
  LIB_MOVED=false

  # Don't use /usr/local for RHEL because it doesn't check there for libs
  if [ -f "/etc/redhat-release" ]; then
    if [ ! -f "/usr/lib/liblfr.so" ]; then
      if [ ${ALKEMIST_RUNTIME_MODE} = 1 ] ; then
        cp ${LFR_ROOT_PATH}/lib/build/* /usr/lib
      fi
      cp ${LFR_ROOT_PATH}/lib/run/liblfr.so /usr/lib/
      LIB_MOVED=true
    fi
  else
    if [ ! -f "/usr/local/lib/liblfr.so" ]; then
      mkdir -p /usr/local/lib
      if [ ${ALKEMIST_RUNTIME_MODE} = 1 ] ; then
        cp ${LFR_ROOT_PATH}/lib/build/* /usr/local/lib
      fi
      cp ${LFR_ROOT_PATH}/lib/run/liblfr.so /usr/local/lib/
      LIB_MOVED=true
    fi
  fi

  if [ $LIB_MOVED = true ]; then
    ldconfig
  fi
fi

env PATH="${LFR_ROOT_PATH}/scripts:${PATH}" \
    LFR_ROOT_PATH=${LFR_ROOT_PATH} \
    TRAPLINKER_ORIG_LD=${orig_ld} \
    LD_LIBRARY_PATH="${LFR_ROOT_PATH}/lib/build:${LD_LIBRARY_PATH}" \
    "${@}"